
##
# maXYpvalue() - simple function for vectorized 2-sided t-test 
# for 2 condition sets of samples. This simple method assumes 
# equal variances.
# Function:  maXYpvalue(xSet, ySet)
# @param xSet and ySet are [1:nGene,1:nX or 1:nY] matrices or
#        data frames
# @return 2-sided p-value list from doing t.test for each gene
#
# By Mariusz Lubomirski and Greg Alvord, CSS/DMS, NCI-Frederick 
##
maXYpvalue <- function(xSet,ySet) 
{ # maXYpvalue 
  xSet.na.mat <- is.na(xSet);
  ySet.na.mat <- is.na(ySet);

  # Collect numeric values only
  nX <- apply(!xSet.na.mat,1,sum);
  nY <- apply(!ySet.na.mat,1,sum);

  # Calculate degrees of freedom
  ndf <- nX + nY - 2;

  s2 <- ( (nX-1)*apply(xSet,1,var,na.rm=T) + 
          (nY-1)*apply(ySet,1,var,na.rm=T) ) / ndf;
  t.stat <- ( apply(xSet,1,mean,na.rm=T) - 
              apply(ySet,1,mean,na.rm=T) ) / 
            sqrt(s2*(1/nX+1/nY));
  p.val.2.sided <- 2 * (1-pt(abs(t.stat), ndf));

  return(p.value=p.val.2.sided); 
} # end of maXYpvalue 
